==> camel-base-3.1.0-sources.jar: org/apache/camel/impl/converter/ToStringTypeConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl.converter;

import java.util.HashSet;
import java.util.Set;
import java.util.concurrent.Future;

import org.apache.camel.Exchange;
import org.apache.camel.Message;
import org.apache.camel.WrappedFile;
import org.apache.camel.support.TypeConverterSupport;

/**
 * A simple converter that can convert any object to a String type by using the
 * toString() method of the object.
 */
public class ToStringTypeConverter extends TypeConverterSupport {

    static Set<Class<?>> missTypes = new HashSet<>();

    public static void registerMissType(Class clazz) {
        missTypes.add(clazz);
    }

    static {
        registerMissType(Message.class);
        registerMissType(Future.class);
        registerMissType(WrappedFile.class);
    }

    @SuppressWarnings("unchecked")
    @Override
    public <T> T convertTo(Class<T> toType, Exchange exchange, Object value) {

        // should not try to convert specific types
        if (missTypes.stream().anyMatch(cl -> cl.isAssignableFrom(value.getClass()))) {
            return (T) MISS_VALUE;
        }

        if (toType.equals(String.class)) {
            return (T) value.toString();
        }
        return null;
    }

}

==> camel-base-3.4.5-sources.jar: org/apache/camel/impl/converter/ToStringTypeConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl.converter;

import java.util.concurrent.Future;

import org.apache.camel.Exchange;
import org.apache.camel.Message;
import org.apache.camel.WrappedFile;
import org.apache.camel.support.TypeConverterSupport;

/**
 * A simple converter that can convert any object to a String type by using the
 * toString() method of the object.
 */
public class ToStringTypeConverter extends TypeConverterSupport {

    @SuppressWarnings("unchecked")
    @Override
    public <T> T convertTo(Class<T> toType, Exchange exchange, Object value) {

        // should not try to convert these specific types
        if (value instanceof Message || value instanceof WrappedFile || value instanceof Future) {
            return (T) MISS_VALUE;
        }

        if (toType.equals(String.class)) {
            return (T) value.toString();
        }
        return null;
    }

}
